
// Uncommentment for debugging purposes:
//          What are the versions of the host/apis 
//                    DisplayVersionInfo();
//
//          When a script is called, it is given information about why it was triggered. 
//                  DisplayTriggerParameters();
//
//          List of effective policies currently being enforced:
//                  DisplayEffectivePolicies();
//
//          List of Locations currently assigned:
//                  DisplayAssignedLocation();
//
//          List of Network/Configuration Locations available:
//                  DisplayNetworkLocations();
//
//          If you want to see the current Location Information
//                  DisplayLocationInformation();
//
//          Information about this script in the system
//                    DisplayThisScriptInfo()
//
//          Information about other scripts in the system -- not documented.
//                    DisplayScripts();
//
//          Information about the current hardware control settings
//                  DisplayAdapterTypesConnected()
//                  DisplayHardwareDisabled();
//                  DisplayHardwareEnforcement();
//
//           WiFi policy information
//                  DisplayWiFiPolicy();
//
//           Volume Policy
                    DisplayVolumePolicy();
//


function DisplayVersion(name)
{
    Action.Trace( name + ": " + Query.Version(name, "Major") + "." + Query.Version(name, "Minor") + "." + Query.Version(name, "Revision") + "." + Query.Version(name, "Build"));
}

function DisplayVersionInfo()
{
    Action.Trace("");
    Action.Trace(" ******** Version Information ********* ");
    Action.Trace("");
    DisplayVersion("Client");
    DisplayVersion("Query");
    DisplayVersion("Action");
    DisplayVersion("Storage");
}


function DisplayLocationInformation()
{
    // Displayed as part of the LocationChangeReason
    //Action.Trace("");
    //Action.Trace(" ******** Security Location ********* ");
    //Action.Trace("");
    //DisplayAssignedLocation(Query.SecurityLocation);

    ret = Query.LocationChangeReason;  // this is currently not documented in appendix
    Action.Trace("");
    Action.Trace(" ******** Change Reason ********* ");
    Action.Trace("");
    DisplayChangeReason(ret);

    Action.Trace("");
    Action.Trace(" ******** Assigned Location ********* ");
    Action.Trace("");
    DisplayAssignedLocation(Query.AssignedLocation);

    Action.Trace("");
    Action.Trace(" ******** Mobile Location ********* ");
    Action.Trace("");
    var mobile = Query.MobileLocation;
    DisplayAssignedLocation(mobile);

    Action.Trace("");
    Action.Trace(" ******** Network Location ********* ");
    Action.Trace("");
    DisplayNetworkLocation(Query.NetworkLocation);
}

function DisplayChangeReason(ret) 
{
    Action.Trace("Reason : " + ret.Reason);
    Action.Trace("Producer: " + ret.Producer);
    Action.Trace("RuleId: " + ret.RuleId);
    Action.Trace("RuleName: " + ret.RuleName);
    Action.Trace("Level: " + ret.Level);
    Action.Trace(" ******** Current Security Location ********* ");
    DisplayAssignedLocation(ret.SecurityLocation);
}

function DisplayAssignedLocation(loc) 
{
    Action.Trace("Location = " + loc.Name);
    Action.Trace("Id = " + loc.Id);
    Action.Trace("Date Modified = " + loc.DateModified);
    Action.Trace("Order: " + loc.Order);
    Action.Trace("Mobile: " + loc.Mobile);
    Action.Trace("Allow Manual Change: " + loc.AllowsManualChange);
    Action.Trace("Show in menu: " + loc.ShowInMenu);
}


function DisplayNetworkLocation(loc) 
{
    Action.Trace("Location = " + loc.Name);
    Action.Trace("Id = " + loc.Id);
    Action.Trace("Date Modified = " + loc.DateModified);
    Action.Trace("Order: " + loc.Order);
    Action.Trace("Mobile: " + loc.Mobile);
}

function DisplayTriggerParameters()
{
    Action.Trace("");
    Action.Trace(" ******** Trigger Parameters ********* ");
    Action.Trace("");
    Action.Trace("Reason = " + Query.TriggerParameter("reason"));
    Action.Trace("Parameter Count = " + Query.TriggerParameterCount);
    for(var idx = 0; idx < Query.TriggerParameterCount; idx++)
    {
        Action.Trace("Parameter: " + Query.TriggerParameterName(idx) + " -> " + Query.TriggerParameterValue(idx));
    }
}

function DisplayEffectivePolicies()
{
    Action.Trace(" ******** Effective Policy List Access ****** ");
    var ret = Query.EffectivePolicyList();
    for(var i = 0; i < ret.Count; i++)
    {
        var pol = ret.Item(i);
        Action.Trace(" ******** Policy Information ********* ");
        Action.Trace("ID: " + pol.Id);
        Action.Trace("Version: " + pol.Version);
        Action.Trace("Name: " + pol.Name);
        Action.Trace("Type: " + pol.PolicyType);
        Action.Trace("Session: " + pol.Session);
    }
}

function DisplayThisScriptInfo (script)
{
        Action.Trace("");
        Action.Trace(" ******** This Script Information ********* ");
        Action.Trace("Script Name: " + Query.ScriptName);
        Action.Trace("Script ID: " + Query.ScriptID);
        Action.Trace("Script Version: " + Query.ScriptVersion); // Not in Documentation
        Action.Trace("Script Context: " + Query.ScriptContext);
}


function DisplayScriptInfo (script)
{
    Action.Trace("\t******** Script Information ********* ");
    Action.Trace("\tID: " + script.Id);
    Action.Trace("\tVersion: " + script.Version);
    Action.Trace("\tName: " + script.Name);
    Action.Trace("\tContext: " + script.Context);
    Action.Trace("\tLanguage: " + script.Language);
    Action.Trace("\tRunning: " + script.Running);
    Action.Trace("\tLast Run: " + script.LastRun);
    Action.Trace("\tRuns: " + script.Requests);
    Action.Trace("\tMissed: " + script.MissedRequests);
    Action.Trace("\tErrors: " + script.Errors);
    Action.Trace("\tLast Error: " + script.LastError);
}

function DisplayScripts()
{
    Action.Trace(" ******** List Scripts ****** ");
    var ret = Query.ScriptList();  // Not Documentmented
    for(var i = 0; i < ret.Count; i++)
    {
        DisplayScriptInfo(ret.Item(i));
    }
}


function DisplayHardwareEnforcement()
{
    Action.Trace("");
    Action.Trace("");
    Action.Trace("Hardware Enforcement:");
    Action.Trace("\tfirewire: " + Query.GetHardwareEnforcement("firewire"));
    Action.Trace("\tirda: " + Query.GetHardwareEnforcement("irda"));
    Action.Trace("\tbluetooth: " + Query.GetHardwareEnforcement("bluetooth"));
    Action.Trace("\tports: " + Query.GetHardwareEnforcement("ports"));
    Action.Trace("\tmodem: " + Query.GetHardwareEnforcement("modem"));
    Action.Trace("\twireless: " + Query.GetHardwareEnforcement("wireless"));
    Action.Trace("\twired: " + Query.GetHardwareEnforcement("wired"));
    Action.Trace("\tbridge: " + Query.GetHardwareEnforcement("bridge"));
    Action.Trace("");
    Action.Trace("");
}

function DisplayHardwareDisabled()
{
    Action.Trace("");
    Action.Trace("");
    Action.Trace("Is Hardware Disabled:");
    Action.Trace("\tfirewire: " + Query.IsHardwareDisabled("firewire"));
    Action.Trace("\tirda: " + Query.IsHardwareDisabled("irda"));
    Action.Trace("\tbluetooth: " + Query.IsHardwareDisabled("bluetooth"));
    Action.Trace("\tports: " + Query.IsHardwareDisabled("ports"));
    Action.Trace("\tmodem: " + Query.IsHardwareDisabled("modem"));
    Action.Trace("\twireless: " + Query.IsHardwareDisabled("wireless"));
    Action.Trace("\twired: " + Query.IsHardwareDisabled("wired"));
    Action.Trace("\tbridge: " + Query.IsHardwareDisabled("bridge"));
    Action.Trace("");
    Action.Trace("");
}

function DisplayAdapterTypesConnected()
{
    Action.Trace("");
    Action.Trace("");
    Action.Trace("Adapter Type Connected:");
    Action.Trace("\twired: " + Query.IsAdapterTypeConnected("wired"));
    Action.Trace("\twireless: " + Query.IsAdapterTypeConnected("wireless"));
    Action.Trace("\tmodem: " + Query.IsAdapterTypeConnected("modem"));
    Action.Trace("\tany: " + Query.IsAdapterTypeConnected("any"));
    Action.Trace("");
    Action.Trace("");
}

function DisplayWiFiPolicy() {
    Action.Trace("Ad hoc: " + Query.GetAdhoc); 
    Action.Trace("Ad hoc(Policy): " + Query.GetAdhocPolicy); 
    Action.Trace("Ad hoc(Script): " + Query.GetAdhocScript);
    Action.Trace("Block Connections: " + Query.GetBlockWiFiConnections);
    Action.Trace("Block Connections(Policy): " + Query.GetBlockWiFiConnectionsPolicy);
    Action.Trace("Block Connections(Script): " + Query.GetBlockWiFiConnectionsScript);
    Action.Trace("Minimum Security Level: " + Query.GetMinWiFiSecurityLevel);
    Action.Trace("Minimum Security Level(Policy): " + Query.GetMinWiFiSecurityLevelPolicy);
    Action.Trace("Minimum Security Level(Script): " + Query.GetMinWiFiSecurityLevelScript);
    Action.Trace("Minimum Signal Level: " + Query.GetMinWiFiSignalLevel);
    Action.Trace("Minimum Signal Level(Policy): " + Query.GetMinWiFiSignalLevelPolicy);
    Action.Trace("Minimum Signal Level(Script): " + Query.GetMinWiFiSignalLevelScript);
}


function DisplayVolumeEnforcement(userType) {
    Action.Trace("Volume Enforcement: " + Query.GetVolumeEnforcement(userType));
    Action.Trace("Volume Enforcement (Policy): " + Query.GetVolumePolicyEnforcement(userType));
    Action.Trace("Volume Enforcement (Script): " + Query.GetVolumeScriptEnforcement(userType));
}

function DisplayAutoPlayPolicy() {
    Action.Trace("Auto Play: " + Query.GetAutoPlayEnforcement());
    Action.Trace("Auto Play(Policy): " + Query.GetAutoPlayPolicyEnforcement());
    Action.Trace("Auto Play(Script): " + Query.GetAutoPlayScriptEnforcement());
}


function DisplayVolumePolicy() {
    DisplayAutoPlayPolicy();
    DisplayVolumeEnforcement("optical");
    DisplayVolumeEnforcement("floppy");
    DisplayVolumeEnforcement("removable");
}