        Action.Trace("Create script firewall in sandbox")

        var ret = Action.CreateFWSandbox("closed");
        if (ret != 0)
            Action.Trace("Create FW Sandbox failed: " + ret);

        ret = Action.AddStandardControlToFWSandbox("arp", "enabled");
        if (ret != 0)
            Action.Trace("Add Standard Control To Sandbox failed: " + ret);


        ret = Action.AddStandardPortRuleToFWSandbox("arp", "open");
        if (ret != 0)
            Action.Trace("Add Standard Port Rule To Sandbox failed: " + ret);

        ret = Action.AddPortRuleToFWSandbox("udp", "open", 80, 100);
        if (ret != 0)
            Action.Trace("Add Ports To Sandbox failed (80-100): " + ret);

        ret = Action.AddPortRuleToFWSandbox("udp", "stateful", 75, 85);
        if (ret != 0)
            Action.Trace("Add Ports To Sandbox failed (75-85): " + ret);

        ret = Action.AddStandardAclToFWSandbox("dns", "trusted");
        if (ret != 0)
            Action.Trace("Add Standard Acl To Sandbox failed: " + ret);

        ret = Action.AddAclToFWSandbox("ip", "trusted", "137.65.1.1-137.65.1.200");
        if (ret != 0)
            Action.Trace("Add Acl To Sandbox failed: " + ret);

        ret = Action.AddAclToFWSandbox("ip", "not_trusted", "137.65.1.6");
        if (ret != 0)
            Action.Trace("Add Acl To Sandbox failed: " + ret);

        ret = Action.AddAclToFWSandbox("ip", "not_trusted", "137.40.1.6");
        if (ret != 0)
            Action.Trace("Add Acl To Sandbox failed: " + ret);
            
        ret = Action.AddAclToFWSandbox("ip", "trusted", "137.40.1.1/24");
        if (ret != 0)
            Action.Trace("Add Acl To Sandbox failed: " + ret);

        ret = Action.AddAclPortsToFWSandbox("ip", "10.10.1.1", "udp", "open", 10, 20);
        if (ret != 0)
            Action.Trace("Add Acl To Sandbox failed: " + ret);

        Action.Trace("Display script firewall in sandbox")
        var sandbox = Query.GetFirewallSandbox();
        if (sandbox == null)
            Action.Trace("Sandbox not found");
        else
            DisplayFirewall(sandbox);

        ret = Action.PublishFWSandbox("My Script Firewall id", "My Script Firewall Name");
        if (ret != 0) {
            Action.Trace("Add Publish Sandbox failed: " + ret);
        }

        DisplayFirewalls();


        ret = Action.AddFWRelationRule("abc", 50, "My Script Firewall Name", "any", "", "Nortel", "");
        ret = Action.AddFWRelationRule("abc2", 50, "all open", "any", "", "Nortel", "00:ff:07:61:7d:ff");

        if (ret != 0) {
            Action.Trace("Add Add FW Relation Rule failed: " + ret);
        }
        DisplayFirewallRelationRules();
        DisplayFirewallAdapters();




        



function DisplayVersion(name)
{
    Action.Trace( name + ": " + Query.Version(name, "Major") + "." + Query.Version(name, "Minor") + "." + Query.Version(name, "Revision") + "." + Query.Version(name, "Build"));
}

function DisplayVersionInfo()
{
    Action.Trace("");
    Action.Trace(" ******** Version Information ********* ");
    Action.Trace("");
    DisplayVersion("Client");
    DisplayVersion("Query");
    DisplayVersion("Action");
    DisplayVersion("Storage");
}


function DisplayTriggerParameters()
{
    Action.Trace("");
    Action.Trace(" ******** Trigger Parameters ********* ");
    Action.Trace("");
    Action.Trace("Reason = " + Query.TriggerParameter("reason"));
    Action.Trace("Parameter Count = " + Query.TriggerParameterCount);
    for(var idx = 0; idx < Query.TriggerParameterCount; idx++)
    {
        Action.Trace("Parameter: " + Query.TriggerParameterName(idx) + " -> " + Query.TriggerParameterValue(idx));
    }
}

function DisplayThisScriptInfo (script)
{
        Action.Trace("");
        Action.Trace(" ******** This Script Information ********* ");
        Action.Trace("Script Name: " + Query.ScriptName);
        Action.Trace("Script ID: " + Query.ScriptID);
        Action.Trace("Script Version: " + Query.ScriptVersion); // Not in Documentation
        Action.Trace("Script Context: " + Query.ScriptContext);
}


function DisplayScriptInfo (script)
{
    Action.Trace("\t******** Script Information ********* ");
    Action.Trace("\tID: " + script.Id);
    Action.Trace("\tVersion: " + script.Version);
    Action.Trace("\tName: " + script.Name);
    Action.Trace("\tContext: " + script.Context);
    Action.Trace("\tLanguage: " + script.Language);
    Action.Trace("\tRunning: " + script.Running);
    Action.Trace("\tLast Run: " + script.LastRun);
    Action.Trace("\tRuns: " + script.Requests);
    Action.Trace("\tMissed: " + script.MissedRequests);
    Action.Trace("\tErrors: " + script.Errors);
    Action.Trace("\tLast Error: " + script.LastError);
}

function DisplayScripts()
{
    Action.Trace(" ******** List Scripts ****** ");
    var ret = Query.ScriptList();  // Not Documentmented
    for(var i = 0; i < ret.Count; i++)
    {
        DisplayScriptInfo(ret.Item(i));
    }
}

function DisplayFWSettings(setting) {
    Action.Trace("        " + setting.Name + " -> " + setting.Value);
}

function DisplayFWPort(port) {
    Action.Trace("        " + port.Type + " : " + port.Behavior + " -> " + port.Start + " - " + port.End);
}

function DisplayFWAcl(acl) {
    var aclString = acl.Behavior + " : " + acl.Type + " -> " + acl.Value;
    if (acl.MacAddress != "") {
        aclString = aclString + "," + acl.MacAddress;
    } 
    Action.Trace("        " + aclString);
    if (acl.Behavior == "port_defined") {
        var ret = acl.GetPortList();  // Not Documentmented
        if (ret.Count > 0) {
            Action.Trace("Ports:");
            for (var i = 0; i < ret.Count; i++) {
                DisplayFWPort(ret.Item(i));
            }
        }
    }
}

function DisplayFirewall(firewall) {
    Action.Trace(" ******** Firewall Info ****** ");
    Action.Trace("Id: " + firewall.Id);
    if (firewall.Name != "")
        Action.Trace("Name: " + firewall.Name);
    Action.Trace("Behavior: " + firewall.Behavior);
    if (firewall.RuleId != "")
        Action.Trace("Rule Id: " + firewall.RuleId);
    if (firewall.RuleName != "")
        Action.Trace("Rule Name: " + firewall.RuleName);

    var ret = firewall.GetStandardControlList();  // Not Documentmented
    if (ret.Count > 0) {
        Action.Trace("Standard Control:");
        for (var i = 0; i < ret.Count; i++) {
            DisplayFWSettings(ret.Item(i));
        }
    }

    var ret = firewall.GetStandardPortRuleList();  // Not Documentmented
    if (ret.Count > 0) {
        Action.Trace("Standard Port Rules:");
        for (var i = 0; i < ret.Count; i++) {
            DisplayFWSettings(ret.Item(i));
        }
    }

    var ret = firewall.GetPortRuleList();  // Not Documentmented
    if (ret.Count > 0) {
        Action.Trace("Ports:");
        for (var i = 0; i < ret.Count; i++) {
            DisplayFWPort(ret.Item(i));
        }
    }

    var ret = firewall.GetStandardAclList();  // Not Documentmented
    if (ret.Count > 0) {
        Action.Trace("Standard Acl:");
        for (var i = 0; i < ret.Count; i++) {
            DisplayFWSettings(ret.Item(i));
        }
    }

    var ret = firewall.GetAclList();  // Not Documentmented
    if (ret.Count > 0) {
        Action.Trace("ACLs:");
        for (var i = 0; i < ret.Count; i++) {
            DisplayFWAcl(ret.Item(i));
        }
    }

}

function DisplayFirewalls()
 {
     Action.Trace(" ******** List Firewall ****** ");
     var ret = Query.GetFirewallList();  // Not Documentmented
     for (var i = 0; i < ret.Count; i++) {
         DisplayFirewall(ret.Item(i));
     }
 }

 function DisplayFirewallSandboxes() {
     Action.Trace(" ******** List Firewall Sandboxes ****** ");
     var ret = Query.GetFirewallSandboxList();  // Not Documentmented
     for (var i = 0; i < ret.Count; i++) {
         DisplayFirewall(ret.Item(i));
     }
 }


 function DisplayFWAdapterInfo(adapter) {
     Action.Trace(" ******** FW Adapter Info ****** ");
     Action.Trace("Adapter: ");
     Action.Trace("   Id: " + adapter.Id);
     Action.Trace("   Name: " + adapter.Name);
     Action.Trace("   Device: " + adapter.Device);
     Action.Trace("   Friendly Name: " + adapter.FriendlyName);
     Action.Trace("   Type: " + adapter.AdapterType);
     Action.Trace("   Current MAC: " + adapter.CurrentMac);
     Action.Trace("   Permanent MAC: " + adapter.PermanentMac);
     Action.Trace("Firewall:");
     Action.Trace("   Id: " + adapter.FirewallId);
     Action.Trace("   Name: " + adapter.FirewallName);
     Action.Trace("Rule:");
     Action.Trace("   Relation Tag: " + adapter.RelationTag);
     Action.Trace("   Id: " + adapter.RuleId);
     Action.Trace("   Name: " + adapter.RuleName);
     Action.Trace("   Level: " + adapter.RuleLevel);
 }

 function DisplayFirewallAdapters() {
     Action.Trace(" ******** List Firewall to Adapter information ****** ");
     var ret = Query.GetFWAdapterList();  // Not Documentmented
     for (var i = 0; i < ret.Count; i++) {
         DisplayFWAdapterInfo(ret.Item(i));
     }
 }

 function DisplayFWRelationRule(rule) {
     Action.Trace(" ******** FW Relation Rule ****** ");
     Action.Trace("Tag: " + rule.Tag);
     Action.Trace("Adapter: ");
     if (rule.AdapterType != "any")
        Action.Trace("   Type: " + rule.AdapterType);
     if (rule.AdapterId != "")
        Action.Trace("   Id: " + rule.AdapterId);
     if (rule.FriendlyName != "")
         Action.Trace("   Friendly Name: " + rule.FriendlyName);
     if (rule.MacAddress != "")
         Action.Trace("   Mac Address: " + rule.MacAddress);

     Action.Trace("Firewall:");
     Action.Trace("   Id: " + rule.FirewallId);
     Action.Trace("   Name: " + rule.FirewallName);

     Action.Trace("Producer:");
     Action.Trace("   Name: " + rule.ProducerName);
     Action.Trace("   Feature: " + rule.ProducerFeature);

     Action.Trace("Rule");
     Action.Trace("   Name:  " + rule.RuleName);
     Action.Trace("   Id:    " + rule.RuleId);
     Action.Trace("   Level: " + rule.RuleLevel);
     Action.Trace("   Established: " + rule.Established);
     if (rule.Comment != "")
        Action.Trace("   Comment: " + rule.Comment);
 }

 function DisplayFirewallRelationRules() {
     Action.Trace(" ******** List Firewall Relation Rules ****** ");
     var ret = Query. GetFWRelationRuleList();  // Not Documentmented
     for (var i = 0; i < ret.Count; i++) {
         DisplayFWRelationRule(ret.Item(i));
     }
 }

