// When setting up this script, the following conditions must be meet.
// The user/device/zone must contain a location called "Quarentine". 
//     At this location the security policies should restrict the device/user to only those actions allowed.
//     The Quarentine location should be setup to not allow manual changes in or out of it.
//
// A "Location Assignment Policy" should be published so "Quarentine" is a valid security location.
// A "Scripting Policy" should be published with this script.
//    "Scripting Policy" should be triggered 
//                           "Enforcement of this Policy", 
//                           "Time Tigger" value of 1 minute


// Debug messages ONLY work through Rule Scripting test interface or
// with debug output tools (like Dbgview.exe) when ZESService/ZESUser has been started with HKLM/Software/Novell-ZES/Log/DbgTracing is set to 1
// this will NOT run in standard WSH (you would have to replace them with WScript.Echo (which won't run in the policy script)
Action.Trace("AV Watcher has started");



// Uncommentment for debugging purposes:
//          When a script is called, it is given information about why it was triggered. 
//                     DisplayTriggerParameters();
//
//          If you want to see the set of policies being applied:
//                     DisplayEffectivePolicies();
//
//          If you want to see the set of Locations assigned to the box:
//                     DisplayAssignedLocation();
//
//          If you want to see the set of Network/Configuration Locations assigned to the box:
//                     DisplayNetworkLocations();
//
//          If you want to see the current Security Location and the reason this location was chosen
// 


var locationName = "Quarentine";
var processList = new Array("calc.exe");
var locationChangePriority = 100;


var bQuarantineFound = Storage.GetNameValue("CheckedForQuarentine"); 
if (Query.TriggerParameter("EType") == 37)
{
    bQuarantineFound="False";
    Action.Trace("New Policy Recieved");
}

if (bQuarantineFound == "False" || bQuarantineFound == "")
{
    list = Query.AssignedLocationList;
    for (idx = 0; idx < list.Count; idx++)
    {
        loc = list.Item(idx);
        if (loc.Name.toLowerCase() == locationName.toLowerCase())
        {
            bQuarantineFound = "True";
        }
    }
    Storage.SetNameValue("CheckedForQuarentine", bQuarantineFound);
}

if (bQuarantineFound == "True")
{
    var haveMatch = false;

 
    for (i=0; i< processList.length; i++) {
 
            var proc = processList[i].toLowerCase();
 
            var e = new Enumerator (GetObject("winmgmts:").InstancesOf("Win32_process"));
 
            for (; !e.atEnd(); e.moveNext()) {
                    var p = e.item ();
                    curproc = p.Name.toLowerCase();
                    if (curproc == proc) 
                    {
                        Action.Trace("found: " + curproc);
                        haveMatch = true;
                        break;
                    }
            }
    }

    if (Query.SecurityLocation.Name.toLowerCase() == locationName.toLowerCase())
    {
        if (haveMatch == true)
        {
            var locationChange = Action.PermanentLocationChange(Query.AssignedLocation.Id, locationChangePriority);
            if (locationChange.Rule != Query.ScriptName)
            {
                Action.Trace("Return to assigned location failed:");
                DisplayChangeReason(locationChange);
            }

            var locationChange = Action.ReenableLocationDecider(locationChangePriority);
            if (locationChange.Rule != Query.ScriptName)
            {
                Action.Trace("Re-enable location decider failed:");
                DisplayChangeReason(locationChange);
            }
        }
    }
    else
    {
        if (haveMatch != true)
        {
            var locationChange = Action.PermanentLocationChange(locationName, locationChangePriority);
            if (locationChange.Rule != Query.ScriptName)
            {
                Action.Trace("1st time PermanentLocationChange failed:");
            
                DisplayChangeReason(locationChange);
            }
        }
    }
}
else
{
    Action.DisplayMessage("AV Checker", locationName  + " location has not been assigned to the device", "info", 15);
}


function DisplayChangeReason(ret) 
{
    Action.Trace("Reason : " + ret.Reason);
    Action.Trace("Producer: " + ret.Producer);
    Action.Trace("RuleId: " + ret.RuleId);
    Action.Trace("RuleName: " + ret.RuleName);
    Action.Trace("Level: " + ret.Level);
    DisplayAssignedLocation(ret.SecurityLocation);
}

function DisplayAssignedLocation(loc) 
{
    Action.Trace("Location = " + loc.Name);
    Action.Trace("Id = " + loc.Id);
    Action.Trace("Date Modified = " + loc.DateModified);
    Action.Trace("Order: " + loc.Order);
    Action.Trace("Mobile: " + loc.Mobile);
    Action.Trace("Allow Manual Change: " + loc.AllowsManualChange);
    Action.Trace("Show in menu: " + loc.ShowInMenu);
}


function DisplayNetworkLocation(loc) 
{
    Action.Trace("Location = " + loc.Name);
    Action.Trace("Id = " + loc.Id);
    Action.Trace("Date Modified = " + loc.DateModified);
    Action.Trace("Order: " + loc.Order);
    Action.Trace("Mobile: " + loc.Mobile);
}

function DisplayTriggerParameters()
{
    Action.Trace("");
    Action.Trace(" ******** Trigger Parameters ********* ");
    Action.Trace("");
    Action.Trace("Reason = " + Query.TriggerParameter("reason"));
    Action.Trace("Parameter Count = " + Query.TriggerParameterCount);
    for(var idx = 0; idx < Query.TriggerParameterCount; idx++)
    {
        Action.Trace("Parameter: " + Query.TriggerParameterName(idx) + " -> " + Query.TriggerParameterValue(idx));
    }
}

function DisplayEffectivePolicies()
{
    Action.Trace(" ******** Effective Policy List Access ****** ");
    var ret = Query.EffectivePolicyList();
    for(var i = 0; i < ret.Count; i++)
    {
        var pol = ret.Item(i);
        Action.Trace(" ******** Policy Information ********* ");
        Action.Trace("ID: " + pol.Id);
        Action.Trace("Version: " + pol.Version);
        Action.Trace("Name: " + pol.Name);
        Action.Trace("Type: " + pol.PolicyType);
        Action.Trace("Session: " + pol.Session);
    }
}

